@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
@@ -137,10 +137,17 @@ RULE
     return $database;
 }
 
+has _prolog => (
+    is => 'lazy',
+);
+sub _build__prolog {
+    my ($self) = @_;
+    return AI::Prolog->new($self->_database);
+}
+
 
 sub chord_key {
     my ($self) = @_;
-    my $prolog = AI::Prolog->new($self->_database);
     my $query = sprintf 'chord_key(%s, %s, %s, %s, %s).',
         defined $self->chord_note   ? $self->chord_note   : 'ChordNote',
         defined $self->chord        ? $self->chord        : 'Chord',
@@ -148,18 +155,12 @@ sub chord_key {
         defined $self->key          ? $self->key          : 'Key',
         defined $self->key_function ? $self->key_function : 'KeyFunction',
     ;
-    $prolog->query($query);
-    my @return;
-    while (my $result = $prolog->results) {
-        push @return, $result;
-    }
-    return \@return;
+    return $self->_querydb($query);
 }
 
 
 sub pivot_chord_keys {
     my ($self) = @_;
-    my $prolog = AI::Prolog->new($self->_database);
     my $query = sprintf 'pivot_chord_keys(%s, %s, %s, %s, %s, %s, %s, %s).',
         defined $self->chord_note    ? $self->chord_note    : 'ChordNote',
         defined $self->chord         ? $self->chord         : 'Chord',
@@ -170,9 +171,14 @@ sub pivot_chord_keys {
         defined $self->key           ? $self->key           : 'Key',
         defined $self->key_function  ? $self->key_function  : 'KeyFunction',
     ;
-    $prolog->query($query);
+    return $self->_querydb($query);
+}
+
+sub _querydb {
+    my ($self, $query) = @_;
+    $self->_prolog->query($query);
     my @return;
-    while (my $result = $prolog->results) {
+    while (my $result = $self->_prolog->results) {
         push @return, $result;
     }
     return \@return;
@@ -192,13 +198,13 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
   use Music::ModalFunction ();
 
-  # What key(s) have a Dmaj dominant chord?
+  # What mode(s) have a Dmaj dominant chord?
   my $m = Music::ModalFunction->new(
     chord_note   => 'd',
     chord        => 'maj',
@@ -208,7 +214,7 @@ version 0.0200
   # [['chord_key','d','maj','g','ionian','dominant'],
   #  ['chord_key','d','maj','g','lydian','dominant']]
 
-  # In what key(s) can a Gmaj chord function as a subdominant pivot chord?
+  # In what mode(s) can a Gmaj chord function as a subdominant pivot chord?
   $m = Music::ModalFunction->new(
     chord_note   => 'g',
     chord        => 'maj',
